@@ -1,5 +1,8 @@
 #!/usr/bin/python3
 #
+# Like what you see? Join us!
+# https://www.univention.com/about-us/careers/vacancies/
+#
 # Copyright 2014-2022 Univention GmbH
 #
 # https://www.univention.de/
@@ -56,6 +59,7 @@ if __name__ == '__main__':
 		for iid, ilabel in city_names.items():
 			city_data[iid].setdefault('label', {})[ilocale] = ilabel
 
-	json.dump(list(city_data.values()), opt.outfile, indent=2)
+	json.dump(list(city_data.values()), opt.outfile, ensure_ascii=False, indent=2, sort_keys=True)
+	opt.outfile.write("\n")
 
 	print('... done :)')
