@@ -1,5 +1,8 @@
 #!/usr/bin/python3
 #
+# Like what you see? Join us!
+# https://www.univention.com/about-us/careers/vacancies/
+#
 # Copyright 2014-2022 Univention GmbH
 #
 # https://www.univention.de/
@@ -45,5 +48,7 @@ if __name__ == '__main__':
 
 	print('generating country code data...')
 	pairs = _util.get_country_codes(3)
-	json.dump(pairs, opt.outfile)
+	json.dump(pairs, opt.outfile, ensure_ascii=False, indent=2, sort_keys=True)
+	opt.outfile.write("\n")
+
 	print('... done :)')
