@@ -1,5 +1,8 @@
 #!/usr/bin/python3
 #
+# Like what you see? Join us!
+# https://www.univention.com/about-us/careers/vacancies/
+#
 # Copyright 2014-2022 Univention GmbH
 #
 # https://www.univention.de/
@@ -49,5 +52,7 @@ if __name__ == '__main__':
 	country_ids = set(countries.values())
 	labels = _util.get_localized_names(country_ids, opt.languageCode)
 	final_lables = {icountry: labels.get(igeonameid, '') for icountry, igeonameid in countries.items()}
-	json.dump(final_lables, opt.outfile)
+	json.dump(final_lables, opt.outfile, ensure_ascii=False, indent=2, sort_keys=True)
+	opt.outfile.write("\n")
+
 	print('... done :)')
